@@ -82,20 +82,23 @@ class Gaia:
 
     def save_bigquery_import(self, dataset, table, entries):
         """Save entries to import bucket."""
-        timestamp = datetime.isoformat(datetime.now())
-        blobname = f"{dataset}/{table}_{timestamp}.json"
+        bucketname = BIGQUERY_IMPORTS_BUCKET
+        print(f"Bucket Name: {bucketname}")
+        blobname = f"{dataset}/{table}.json"
+        print(f"Blob Name: {blobname}")
         blobstring = "\n".join([json.dumps(e) for e in entries])
-        blob = storage.Client().bucket(BIGQUERY_IMPORTS_BUCKET).blob(blobname)
+        blob = storage.Client().bucket(bucketname).blob(blobname)
         blob.upload_from_string(blobstring, content_type="application/json")
         return blob
 
     def save_firestore_import(self, dataset, table, entries):
         """Save entries to import bucket."""
+        bucketname = FIRESTORE_IMPORTS_BUCKET
+        print(f"Bucket Name: {bucketname}")
         timestamp = datetime.isoformat(datetime.now())
         blobname = f"{dataset}/{table}_{timestamp}.json"
         print(f"Blob Name: {blobname}")
-        print(f"Bucket Name: {FIRESTORE_IMPORTS_BUCKET}")
         blobstring = json.dumps(entries, sort_keys=True, default=str)
-        blob = storage.Client().bucket(FIRESTORE_IMPORTS_BUCKET).blob(blobname)
+        blob = storage.Client().bucket(bucketname).blob(blobname)
         blob.upload_from_string(blobstring, content_type="application/json")
         return blob
